@@ -1,5 +1,5 @@
 __all__ = ('UserProfilePoint', 'UserProfileObjectPoint', 'RussianProfilePoint', 'RussianProfileObjectPoint',
-           'ProfileObjectPoint', 'UserProfileIpExistsPoint',
+           'ProfileObjectPoint', 'UserProfileIpExistsPoint', 'SetCreditScorePoint',
            )
 
 from expressmoney.api import *
@@ -108,6 +108,10 @@ class UserProfileIpExistsResponseContract(Contract):
     is_exist = serializers.BooleanField()
 
 
+class SetCreditScoreCreateContract(Contract):
+    profile = serializers.IntegerField(min_value=1)
+
+
 class RussianProfileID(ID):
     _service = SERVICE
     _app = 'profiles'
@@ -132,6 +136,12 @@ class UserProfileIpExistsID(ID):
     _view_set = 'user_profile_ip_exists'
 
 
+class SetCreditScoreID(ID):
+    _service = SERVICE
+    _app = 'profiles'
+    _view_set = 'set_credit_score'
+
+
 class UserProfilePoint(CreatePointMixin, ContractPoint):
     _point_id = UserProfileID()
     _create_contract = UserProfileCreateContract
@@ -162,3 +172,8 @@ class UserProfileIpExistsPoint(ResponseMixin, CreatePointMixin, ContractPoint):
     _point_id = UserProfileIpExistsID()
     _create_contract = UserProfileIpExistsCreateContract
     _response_contract = UserProfileIpExistsResponseContract
+
+
+class SetCreditScorePoint(CreatePointMixin, ContractPoint):
+    _point_id = SetCreditScoreID()
+    _create_contract = SetCreditScoreCreateContract
